/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's 21 U.S.C.  851*
* Enhanced Drug Penalty Fiscal Year 2021 file and create a SAS dataset.                  *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\drug851fy21nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = drug851fy21nid ;

DATA library.&dataset ;
INFILE datafile LRECL=563;
INPUT
   USSCIDN  1-7             STMIN851  8-11           STMAX851  12-15       
   DGMIN851  16-19          DGMAX851  20-23          FILED  24-26          
   WITHDRWN  27-29          RELIEF  30-32            CTRELIEF  33-35       
   CRMHT851  36-38          INDTDATE DATE11.         FILEDATE DATE11.      
   PROFFN1  61-64           PROFFN2  65-68           PROFFN3  69-72        
   PROFFN4  73-76           PROFFN5  77-80           PROFFN6  81-84        
   PROFFN7  85-88           PROFFN8  89-92           PROFFN9  93-96        
   PROFFN10  97-100         PROFFN11  101-104        PROFFN12  105-108     
   PROFFN13  109-112        PROFFN14  113-116        PROFFN15  117-120     
   PROFFN16  121-124        PROFFN17  125-128        PROFFN18  129-132     
   PROFFN19  133-136        PROFFN20  137-140        PRSENT1  141-144      
   PRSENT2  145-148         PRSENT3  149-152         PRSENT4  153-156      
   PRSENT5  157-160         PRSENT6  161-164         PRSENT7  165-168      
   PRSENT8  169-172         PRSENT9  173-176         PRSENT10  177-180     
   PRSENT11  181-184        PRSENT12  185-188        PRSENT13  189-192     
   PRSENT14  193-196        PRSENT15  197-200        PRSENT16  201-204     
   PRSENT17  205-208        PRSENT18  209-212        PRSENT19  213-216     
   PRSENT20  217-220        PRSNDT1 DATE11.          PRSNDT2 DATE11.       
   PRSNDT3 DATE11.          PRSNDT4 DATE11.          PRSNDT5 DATE11.       
   PRSNDT6 DATE11.          PRSNDT7 DATE11.          PRSNDT8 DATE11.       
   PRSNDT9 DATE11.          PRSNDT10 DATE11.         PRSNDT11 DATE11.      
   PRSNDT12 DATE11.         PRSNDT13 DATE11.         PRSNDT14 DATE11.      
   PRSNDT15 DATE11.         PRSNDT16 DATE11.         PRSNDT17 DATE11.      
   PRSNDT18 DATE11.         PRSNDT19 DATE11.         PRSNDT20 DATE11.      
   OFFENNUM  441-443        PRCHPT1  444-446         PRCHPT2  447-449      
   PRCHPT3  450-452         PRCHPT4  453-455         PRCHPT5  456-458      
   PRCHPT6  459-461         PRCHPT7  462-464         PRCHPT8  465-467      
   PRCHPT9  468-470         PRCHPT10  471-473        PRCHPT11  474-476     
   PRCHPT12  477-479        PRCHPT13  480-482        PRCHPT14  483-485     
   PRCHPT15  486-488        PRCHPT16  489-491        PRCHPT17  492-494     
   PRCHPT18  495-497        PRCHPT19  498-500        PRCHPT20  501-503     
   PRFELN1  504-506         PRFELN2  507-509         PRFELN3  510-512      
   PRFELN4  513-515         PRFELN5  516-518         PRFELN6  519-521      
   PRFELN7  522-524         PRFELN8  525-527         PRFELN9  528-530      
   PRFELN10  531-533        PRFELN11  534-536        PRFELN12  537-539     
   PRFELN13  540-542        PRFELN14  543-545        PRFELN15  546-548     
   PRFELN16  549-551        PRFELN17  552-554        PRFELN18  555-557     
   PRFELN19  558-560        PRFELN20  561-563      ;                       

FORMAT
   INDTDATE DATE9.          FILEDATE DATE9.          PRSNDT1 DATE9.        
   PRSNDT2 DATE9.           PRSNDT3 DATE9.           PRSNDT4 DATE9.        
   PRSNDT5 DATE9.           PRSNDT6 DATE9.           PRSNDT7 DATE9.        
   PRSNDT8 DATE9.           PRSNDT9 DATE9.           PRSNDT10 DATE9.       
   PRSNDT11 DATE9.          PRSNDT12 DATE9.          PRSNDT13 DATE9.       
   PRSNDT14 DATE9.          PRSNDT15 DATE9.          PRSNDT16 DATE9.       
   PRSNDT17 DATE9.          PRSNDT18 DATE9.          PRSNDT19 DATE9.       
   PRSNDT20 DATE9.        ;
                      

LENGTH
   USSCIDN 6                STMIN851 4               STMAX851 4            
   DGMIN851 4               DGMAX851 4               FILED 3               
   WITHDRWN 3               RELIEF 3                 CTRELIEF 3            
   CRMHT851 3               PROFFN1 4                PROFFN2 4             
   PROFFN3 4                PROFFN4 4                PROFFN5 4             
   PROFFN6 4                PROFFN7 4                PROFFN8 4             
   PROFFN9 4                PROFFN10 4               PROFFN11 4            
   PROFFN12 4               PROFFN13 4               PROFFN14 4            
   PROFFN15 4               PROFFN16 4               PROFFN17 4            
   PROFFN18 4               PROFFN19 4               PROFFN20 4            
   PRSENT1 4                PRSENT2 4                PRSENT3 4             
   PRSENT4 4                PRSENT5 4                PRSENT6 4             
   PRSENT7 4                PRSENT8 4                PRSENT9 4             
   PRSENT10 4               PRSENT11 4               PRSENT12 4            
   PRSENT13 4               PRSENT14 3               PRSENT15 3            
   PRSENT16 3               PRSENT17 3               PRSENT18 3            
   PRSENT19 3               PRSENT20 3               OFFENNUM 3            
   PRCHPT1 3                PRCHPT2 3                PRCHPT3 3             
   PRCHPT4 3                PRCHPT5 3                PRCHPT6 3             
   PRCHPT7 3                PRCHPT8 3                PRCHPT9 3             
   PRCHPT10 3               PRCHPT11 3               PRCHPT12 3            
   PRCHPT13 3               PRCHPT14 3               PRCHPT15 3            
   PRCHPT16 3               PRCHPT17 3               PRCHPT18 3            
   PRCHPT19 3               PRCHPT20 3               PRFELN1 3             
   PRFELN2 3                PRFELN3 3                PRFELN4 3             
   PRFELN5 3                PRFELN6 3                PRFELN7 3             
   PRFELN8 3                PRFELN9 3                PRFELN10 3            
   PRFELN11 3               PRFELN12 3               PRFELN13 3            
   PRFELN14 3               PRFELN15 3               PRFELN16 3            
   PRFELN17 3               PRFELN18 3               PRFELN19 3            
   PRFELN20 3 ;

        

RUN ;
